@@ -28,7 +28,7 @@ has w => 1;
 # is good for security.
 Hash::Util::FieldHash::fieldhash my %AUTH;
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 sub DESTROY { shift->_cleanup }
 
@@ -109,7 +109,10 @@ sub _cleanup {
   # Clean up connections
   delete $self->{pid};
   my $connections = delete $self->{connections};
-  $self->_loop($connections->{$_}{nb})->remove($_) for keys %$connections;
+  for my $c (keys %$connections) {
+    my $loop = $self->_loop($connections->{$c}{nb});
+    $loop->remove($c) if $loop;
+  }
 
   # Clean up active operations
   my $queue = delete $self->{queue} || [];
@@ -617,7 +620,7 @@ the terms of the Artistic License version 2.0.
 
 =head1 SEE ALSO
 
-L<https://github.com/odc/mango>, L<Mojolicious::Guides>,
+L<https://github.com/oliwer/mango>, L<Mojolicious::Guides>,
 L<http://mojolicio.us>.
 
 =cut
